
## CATO-CLI - query.devices:
[Click here](https://api.catonetworks.com/documentation/#query-devices) for documentation on this operation.

### Usage for query.devices:

`catocli query devices -h`

`catocli query devices <json>`

`catocli query devices "$(cat < devices.json)"`

`catocli query devices '{"deviceAttributeCatalogInput": {"pagingInput": {"from": {"from": "Int"}, "limit": {"limit": "Int"}}, "sortOrderInput": {"direction": {"direction": "enum(SortOrder)"}, "priority": {"priority": "Int"}}, "stringFilterInput": {"eq": {"eq": "String"}, "in": {"in": ["String"]}, "neq": {"neq": "String"}, "nin": {"nin": ["String"]}}}, "deviceV2Input": {"deviceSortInput": {"category": {"direction": {"direction": "enum(SortOrder)"}, "priority": {"priority": "Int"}}, "confidence": {"direction": {"direction": "enum(SortOrder)"}, "priority": {"priority": "Int"}}, "firstSeen": {"direction": {"direction": "enum(SortOrder)"}, "priority": {"priority": "Int"}}, "hw": {"manufacturer": {"direction": {"direction": "enum(SortOrder)"}, "priority": {"priority": "Int"}}, "model": {"direction": {"direction": "enum(SortOrder)"}, "priority": {"priority": "Int"}}, "type": {"direction": {"direction": "enum(SortOrder)"}, "priority": {"priority": "Int"}}}, "id": {"direction": {"direction": "enum(SortOrder)"}, "priority": {"priority": "Int"}}, "ip": {"direction": {"direction": "enum(SortOrder)"}, "priority": {"priority": "Int"}}, "lastSeen": {"direction": {"direction": "enum(SortOrder)"}, "priority": {"priority": "Int"}}, "name": {"direction": {"direction": "enum(SortOrder)"}, "priority": {"priority": "Int"}}, "network": {"networkName": {"direction": {"direction": "enum(SortOrder)"}, "priority": {"priority": "Int"}}, "subnet": {"direction": {"direction": "enum(SortOrder)"}, "priority": {"priority": "Int"}}}, "nic": {"macAddress": {"direction": {"direction": "enum(SortOrder)"}, "priority": {"priority": "Int"}}, "vendor": {"direction": {"direction": "enum(SortOrder)"}, "priority": {"priority": "Int"}}}, "os": {"product": {"direction": {"direction": "enum(SortOrder)"}, "priority": {"priority": "Int"}}, "vendor": {"direction": {"direction": "enum(SortOrder)"}, "priority": {"priority": "Int"}}, "version": {"direction": {"direction": "enum(SortOrder)"}, "priority": {"priority": "Int"}}}, "riskScore": {"direction": {"direction": "enum(SortOrder)"}, "priority": {"priority": "Int"}}, "site": {"id": {"direction": {"direction": "enum(SortOrder)"}, "priority": {"priority": "Int"}}, "name": {"direction": {"direction": "enum(SortOrder)"}, "priority": {"priority": "Int"}}}, "user": {"id": {"direction": {"direction": "enum(SortOrder)"}, "priority": {"priority": "Int"}}, "name": {"direction": {"direction": "enum(SortOrder)"}, "priority": {"priority": "Int"}}}}, "deviceV2FilterInput": {"category": {"eq": {"eq": "String"}, "in": {"in": ["String"]}, "neq": {"neq": "String"}, "nin": {"nin": ["String"]}}, "confidence": {"eq": {"eq": "enum(DeviceConfidenceLevel)"}, "in": {"in": "enum(DeviceConfidenceLevel)"}, "neq": {"neq": "enum(DeviceConfidenceLevel)"}, "nin": {"nin": "enum(DeviceConfidenceLevel)"}}, "firstSeen": {"between": {"between": ["DateTime"]}, "eq": {"eq": "DateTime"}, "gt": {"gt": "DateTime"}, "gte": {"gte": "DateTime"}, "in": {"in": ["DateTime"]}, "lt": {"lt": "DateTime"}, "lte": {"lte": "DateTime"}, "neq": {"neq": "DateTime"}, "nin": {"nin": ["DateTime"]}}, "hw": {"manufacturer": {"eq": {"eq": "String"}, "in": {"in": ["String"]}, "neq": {"neq": "String"}, "nin": {"nin": ["String"]}}, "model": {"eq": {"eq": "String"}, "in": {"in": ["String"]}, "neq": {"neq": "String"}, "nin": {"nin": ["String"]}}, "type": {"eq": {"eq": "String"}, "in": {"in": ["String"]}, "neq": {"neq": "String"}, "nin": {"nin": ["String"]}}}, "id": {"eq": {"eq": "ID"}, "in": {"in": ["ID"]}, "neq": {"neq": "ID"}, "nin": {"nin": ["ID"]}}, "ip": {"eq": {"eq": "String"}, "in": {"in": ["String"]}, "neq": {"neq": "String"}, "nin": {"nin": ["String"]}}, "lastSeen": {"between": {"between": ["DateTime"]}, "eq": {"eq": "DateTime"}, "gt": {"gt": "DateTime"}, "gte": {"gte": "DateTime"}, "in": {"in": ["DateTime"]}, "lt": {"lt": "DateTime"}, "lte": {"lte": "DateTime"}, "neq": {"neq": "DateTime"}, "nin": {"nin": ["DateTime"]}}, "name": {"eq": {"eq": "String"}, "in": {"in": ["String"]}, "neq": {"neq": "String"}, "nin": {"nin": ["String"]}}, "network": {"networkName": {"eq": {"eq": "String"}, "in": {"in": ["String"]}, "neq": {"neq": "String"}, "nin": {"nin": ["String"]}}, "subnet": {"eq": {"eq": "String"}, "in": {"in": ["String"]}, "neq": {"neq": "String"}, "nin": {"nin": ["String"]}}}, "nic": {"macAddress": {"eq": {"eq": "MacAddress"}, "in": {"in": ["MacAddress"]}, "neq": {"neq": "MacAddress"}, "nin": {"nin": ["MacAddress"]}}, "vendor": {"eq": {"eq": "String"}, "in": {"in": ["String"]}, "neq": {"neq": "String"}, "nin": {"nin": ["String"]}}}, "os": {"product": {"eq": {"eq": "String"}, "in": {"in": ["String"]}, "neq": {"neq": "String"}, "nin": {"nin": ["String"]}}, "vendor": {"eq": {"eq": "String"}, "in": {"in": ["String"]}, "neq": {"neq": "String"}, "nin": {"nin": ["String"]}}, "version": {"eq": {"eq": "String"}, "in": {"in": ["String"]}, "neq": {"neq": "String"}, "nin": {"nin": ["String"]}}}, "riskScore": {"between": {"between": ["Int"]}, "eq": {"eq": "Int"}, "gt": {"gt": "Int"}, "gte": {"gte": "Int"}, "in": {"in": ["Int"]}, "lt": {"lt": "Int"}, "lte": {"lte": "Int"}, "neq": {"neq": "Int"}, "nin": {"nin": ["Int"]}}, "site": {"eq": {"by": {"by": "enum(ObjectRefBy)"}, "input": {"input": "String"}}, "in": {"by": {"by": "enum(ObjectRefBy)"}, "input": {"input": "String"}}, "neq": {"by": {"by": "enum(ObjectRefBy)"}, "input": {"input": "String"}}, "nin": {"by": {"by": "enum(ObjectRefBy)"}, "input": {"input": "String"}}}, "user": {"eq": {"by": {"by": "enum(ObjectRefBy)"}, "input": {"input": "String"}}, "in": {"by": {"by": "enum(ObjectRefBy)"}, "input": {"input": "String"}}, "neq": {"by": {"by": "enum(ObjectRefBy)"}, "input": {"input": "String"}}, "nin": {"by": {"by": "enum(ObjectRefBy)"}, "input": {"input": "String"}}}}, "pagingInput": {"from": {"from": "Int"}, "limit": {"limit": "Int"}}}, "sortOrderInput": {"direction": {"direction": "enum(SortOrder)"}, "priority": {"priority": "Int"}}}'`

#### Operation Arguments for query.devices ####
`accountId` [ID] - (required) N/A 
`deviceAttributeCatalogInput` [DeviceAttributeCatalogInput] - (optional) N/A 
`deviceV2Input` [DeviceV2Input] - (optional) N/A 
`sortOrderInput` [SortOrderInput] - (optional) N/A 
